win_hotkey::hotkey

Struct HotKey

pub struct HotKey {
    pub mods: Modifiers,
    pub key: Code,
    pub id: u32,
    pub name: Option<String>,
}
A keyboard shortcut that consists of an optional combination of modifier keys (provided by Modifiers) and one key (Code).

Fields

mods: Modifiers

The hotkey modifiers.

key: Code

The hotkey key.

id: u32

The hotkey id.

name: Option<String>

The hotkey name.

Implementations

Source

impl HotKey

pub fn new(mods: Option<Modifiers>, key: Code, name: Option<String>) -> Self

Creates a new hotkey to define keyboard shortcuts throughout your application. Only Modifiers::ALT, Modifiers::SHIFT, Modifiers::CONTROL, and Modifiers::SUPER

pub fn id(&self) -> u32

Returns the id associated with this hotKey which is a hash of the string represention of modifiers and key within this hotKey.

pub fn name(&self) -> Option<String>

pub fn matches( &self, modifiers: impl Borrow<Modifiers>, key: impl Borrow<Code>, ) -> bool

Returns true if this Code and Modifiers matches this hotkey.

pub fn into_string(&self) -> String

Converts this hotkey into a string.