pub enum ModifiersKey {
Alt,
Ctrl,
Shift,
Win,
NoRepeat,
Non,
}Expand description
Modifier Key for hotkeys.
See: fsModifiers from https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-registerhotkey
Variants
Alt
Ctrl
Shift
Win
NoRepeat
This is a virtual modifier key that is used to prevent automatically repeating triggers when the hotkey is being held down. When converting to a VirtualKey, this is mapped to KeyCode 0
Non
Implementations
Sourceimpl ModifiersKey
impl ModifiersKey
Sourcepub fn from_keyname(val: &str) -> Result<Self, HotkeyError>
pub fn from_keyname(val: &str) -> Result<Self, HotkeyError>
Take in a string and interpret it as one of the modifier keys. Possible values are:
- ALT
- CTRL / CONTROL
- SHIFT
- WIN / WINDOWS / SUPER
- NOREPEAT / NO_REPEAT
Sourcepub const fn to_mod_code(&self) -> u32
pub const fn to_mod_code(&self) -> u32
Obtain the modifier code for the ModifiersKey.
See: fsModifiers from https://learn.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-registerhotkey