pub struct WinHotKeyEvent {
pub id: u32,
pub state: HotKeyState,
}Expand description
Describes a global hotkey event emitted when a HotKey is pressed or released.
Fields
id: u32Id of the associated HotKey.
state: HotKeyStateState of the associated HotKey.
Implementations
Sourceimpl WinHotKeyEvent
impl WinHotKeyEvent
Sourcepub fn state(&self) -> HotKeyState
pub fn state(&self) -> HotKeyState
Returns the state of the associated HotKey.
Sourcepub fn receiver<'a>() -> &'a WinHotKeyEventReceiver
pub fn receiver<'a>() -> &'a WinHotKeyEventReceiver
Gets a reference to the event channel’s WinHotKeyEventReceiver
which can be used to listen for global hotkey events.
Note
This will not receive any events if WinHotKeyEvent::set_event_handler has been called with a Some value.
Sourcepub fn set_event_handler<F: Fn(WinHotKeyEvent) + Send + Sync + 'static>(
f: Option<F>,
)
pub fn set_event_handler<F: Fn(WinHotKeyEvent) + Send + Sync + 'static>( f: Option<F>, )
Set a handler to be called for new events. Useful for implementing custom event sender.
Note
Calling this function with a Some value,
will not send new events to the channel associated with WinHotKeyEvent::receiver