pub type WinHotKeyEventReceiver = Receiver<WinHotKeyEvent>;Expand description
A reciever that could be used to listen to global hotkey events.
Aliased Type
struct WinHotKeyEventReceiver { /* private fields */ }pub type WinHotKeyEventReceiver = Receiver<WinHotKeyEvent>;A reciever that could be used to listen to global hotkey events.
struct WinHotKeyEventReceiver { /* private fields */ }