pub struct HotKey {
pub mods: Modifiers,
pub key: Code,
pub id: u32,
pub name: Option<String>,
}Expand description
Fields
mods: ModifiersThe hotkey modifiers.
key: CodeThe hotkey key.
id: u32The hotkey id.
name: Option<String>The hotkey name.
Implementations
Sourceimpl HotKey
impl HotKey
Sourcepub fn new(mods: Option<Modifiers>, key: Code, name: Option<String>) -> Self
pub fn new(mods: Option<Modifiers>, key: Code, name: Option<String>) -> Self
Creates a new hotkey to define keyboard shortcuts throughout your application.
Only Modifiers::ALT, Modifiers::SHIFT, Modifiers::CONTROL, and Modifiers::SUPER
Sourcepub fn id(&self) -> u32
pub fn id(&self) -> u32
Returns the id associated with this hotKey which is a hash of the string represention of modifiers and key within this hotKey.
pub fn name(&self) -> Option<String>
Sourcepub fn into_string(&self) -> String
pub fn into_string(&self) -> String
Converts this hotkey into a string.