HotkeyManager

Struct HotkeyManager 

pub struct HotkeyManager<T> { /* private fields */ }

Implementations

Source

impl<T> HotkeyManager<T>

pub fn set_no_repeat(&mut self, no_repeat: bool)

Enable or disable the automatically applied ModKey::NoRepeat modifier. By default, this option is set to true which causes all hotkey registration calls to add the NoRepeat modifier, thereby disabling automatic retriggers of hotkeys when holding down the keys.

When this option is disabled, the ModKey::NoRepeat can still be manually added while registering hotkeys.

Note: Setting this flag doesn’t change previously registered hotkeys. It only applies to registrations performed after calling this function.