InterruptHandle

Struct InterruptHandle 

pub struct InterruptHandle(/* private fields */);
This handle can be used from any thread and can be used multiple times.

Note

This handle will technically stay valid even after the HotkeyManager is dropped, but it will simply not do anything.

Implementations

Source

impl InterruptHandle

pub fn interrupt(&self)

Interrupt the evet loop of the associated HotkeyManager.