pub struct InterruptHandle(/* private fields */);Expand description
This handle can be used from any thread and can be used multiple times.
Note
This handle will technically stay valid even after the HotkeyManager is dropped, but it will
simply not do anything.
Implementations